<p align="center">
  <a href="https://github.com/yakimchuk-me/js.parse">
    <img height="214" width="214" src="http://upload.wikimedia.org/wikipedia/commons/6/6a/JavaScript-logo.png"/>
  </a>
</p>

# [JS.Parse](https://github.com/yakimchuk-me/js.parse) #
>  Simple JavaScript parsing tool.

## How to install this module?
To install this module use following command at root path of your module:
``` bash
npm install js.parse --save
```

## Useful links
We provide a few pages for understading, how to work with this module:

### [Examples](https://github.com/yakimchuk-me/js.parse/blob/master/EXAMPLES.md) ###
### [API Referrence](https://github.com/yakimchuk-me/js.parse/blob/master/API.md) ###

## What makes this tool?
This tool can parse JavaScript source code into array with node variations.

For example, parse of this source code:

``` javascript
var a = 1;
```

will output this array:

``` javascript
[
    {
        name    : 'The Variable Statement',
        types   : [
            'Reserved Word',
            'Keyword',
            'Statement'
        ]
    },
    {
        name    : 'Variable Name',
        types   : [
            'Word'
        ]
    },
    {
        name    : 'Simple Assignment Operator',
        types   : [
            'Operator'
        ]
    },
    {
        name: 'Integer Number Literal',
        types: [
            'Number Literal'
        ]
    },
    {
        name: 'Semicolon Operator',
        types: [
            'Operator',
            'Statement'
        ]
    }
]
```

## Usage
For use this module, just install them, and use one of methods, produced by this module. They all work synchronously.

``` javascript
var parser, source, result;

parser = require('js.parse'); // Connect the module.

source = 'var a = 1;'; // You need to have source JavaScript code in string.

result = parser.source(source); // Call method 'source' of module, that returns array of objects.

/*
 * Now variable 'result' contains array:
 *
 *   [
 *      {
 *          name    : 'The Variable Statement',
 *          types   : [
 *              'Reserved Word',
 *              'Keyword',
 *              'Statement'
 *          ]
 *      },
 *      {
 *          name    : 'Variable Name',
 *          types   : [
 *              'Word'
 *          ]
 *      },
 *      {
 *          name    : 'Simple Assignment Operator',
 *          types   : [
 *              'Operator'
 *          ]
 *      },
 *      {
 *          name: 'Integer Number Literal',
 *          types: [
 *              'Number Literal'
 *          ]
 *      },
 *      {
 *          name: 'Semicolon Operator',
 *          types: [
 *              'Operator',
 *              'Statement'
 *          ]
 *      }
 *  ]
 *
 */

// Some actions with result of parsing source code ...
```


Of course, you can read contents of your JS files using 'fs' module of NodeJS, and this will work:

``` javascript
var fs;

fs = require('fs');

fs.readFile('somefile.js', 'utf-8', function (error, source) {

    // Now we have contents of file 'somefile.js' in argument source as string

    var parser, result;

    parser = require('js.parse'); // Connect the module.

    result = parser.source(source); // Call method 'source' of module, that returns array of objects.

    // Now variable 'result' contains array with objects (result of parsing file).

    // Some actions with result of parsing source code ...

});
```


For more examples watch page [Examples](https://github.com/yakimchuk-me/js.parse/blob/master/EXAMPLES.md).