'use strict';

module.require('colors');

/**
 * Module that provides an API for parsing of source JavaScript code.
 * @author Roman Yakimchuk
 * @module
 * @constructor
 * @returns {Object} Instance of class.
 */
function JSParse () {

  /**
   * Global variable, means that module works in verbose mode.
   * @author Roman Yakimchuk
   * @private
   * @global
   * @type {Boolean}
   */
  global.__verbose = false;

  /**
   * Method that enables verbose mode.
   * @author Roman Yakimchuk
   * @public
   * @this {Object} Module 'JSParse'
   * @member JSParse
   * @returns {Object} Module 'JSParse'
   */
  this.enableVerboseMode = function () {

    global.__verbose = true;

    return this;

  };

  /**
   * Method that disables verbose mode.
   * @author Roman Yakimchuk
   * @public
   * @this {Object} Module 'JSParse'
   * @member JSParse
   * @returns {Object} Module 'JSParse'
   */
  this.disableVerboseMode = function () {

    global.__verbose = false;

    return this;

  };

  /**
   * Method that converts source JavaScript code into array of node variations.
   * @author Roman Yakimchuk
   * @public
   * @this {Object} Module 'JSParse'
   * @member JSParse
   * @param {String} source String with source JavaScript code.
   * @returns {Array} Array with node instances.
   */
  this.source = function (source) {

    var Parser, Nodes;

    Parser = require('./lib/parser');
    Nodes  = require('./lib/nodes');

    var nodes;

    nodes = Parser.parse(source);

    if (Nodes.isInvalid(nodes)) {

      console.log(
        '    ', 'Unable to parse the source code to work. Method stops working, return an empty array.'.red
      );

      return [];

    }

    console.log(
      '    ', 'Source code successfully parsed! Returns an array with the elements, all the elements:'.green,
      nodes.length
    );

    nodes = Nodes.convert(nodes);

    return nodes;

  }

}

module.exports = new JSParse();